==> core_models-0.1.0.gem: app/controllers/core_models/base/distance_units_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Base::DistanceUnitsController < CoreModelsController
    # GET /base/distance_units
    # GET /base/distance_units.json
    def index
      @base_distance_units = Base::DistanceUnit.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @base_distance_units }
      end
    end

    # GET /base/distance_units/1
    # GET /base/distance_units/1.json
    def show
      @base_distance_unit = Base::DistanceUnit.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @base_distance_unit }
      end
    end

    # GET /base/distance_units/new
    # GET /base/distance_units/new.json
    def new
      @base_distance_unit = Base::DistanceUnit.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @base_distance_unit }
      end
    end

    # GET /base/distance_units/1/edit
    def edit
      @base_distance_unit = Base::DistanceUnit.find(params[:id])
    end

    # POST /base/distance_units
    # POST /base/distance_units.json
    def create
      @base_distance_unit = Base::DistanceUnit.new(params[:base_distance_unit])

      respond_to do |format|
        if @base_distance_unit.save
          format.html { redirect_to @base_distance_unit, :notice => 'Distance unit was successfully created.' }
          format.json { render :json => @base_distance_unit, :status => :created, :location => @base_distance_unit }
        else
          format.html { render :action => "new" }
          format.json { render :json => @base_distance_unit.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /base/distance_units/1
    # PUT /base/distance_units/1.json
    def update
      @base_distance_unit = Base::DistanceUnit.find(params[:id])

      respond_to do |format|
        if @base_distance_unit.update_attributes(params[:base_distance_unit])
          format.html { redirect_to @base_distance_unit, :notice => 'Distance unit was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @base_distance_unit.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /base/distance_units/1
    # DELETE /base/distance_units/1.json
    def destroy
      @base_distance_unit = Base::DistanceUnit.find(params[:id])
      @base_distance_unit.destroy

      respond_to do |format|
        format.html { redirect_to base_distance_units_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/base/distance_units_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Base::DistanceUnitsController < CoreModelsController
    # GET /base/distance_units
    # GET /base/distance_units.json
    def index
      @base_distance_units = Base::DistanceUnit.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @base_distance_units }
      end
    end

    # GET /base/distance_units/1
    # GET /base/distance_units/1.json
    def show
      @base_distance_unit = Base::DistanceUnit.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @base_distance_unit }
      end
    end

    # GET /base/distance_units/new
    # GET /base/distance_units/new.json
    def new
      @base_distance_unit = Base::DistanceUnit.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @base_distance_unit }
      end
    end

    # GET /base/distance_units/1/edit
    def edit
      @base_distance_unit = Base::DistanceUnit.find(params[:id])
    end

    # POST /base/distance_units
    # POST /base/distance_units.json
    def create
      @base_distance_unit = Base::DistanceUnit.new(params[:base_distance_unit])

      respond_to do |format|
        if @base_distance_unit.save
          format.html { redirect_to @base_distance_unit, :notice => 'Distance unit was successfully created.' }
          format.json { render :json => @base_distance_unit, :status => :created, :location => @base_distance_unit }
        else
          format.html { render :action => "new" }
          format.json { render :json => @base_distance_unit.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /base/distance_units/1
    # PUT /base/distance_units/1.json
    def update
      @base_distance_unit = Base::DistanceUnit.find(params[:id])

      respond_to do |format|
        if @base_distance_unit.update(params[:base_distance_unit])
          format.html { redirect_to @base_distance_unit, :notice => 'Distance unit was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @base_distance_unit.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /base/distance_units/1
    # DELETE /base/distance_units/1.json
    def destroy
      @base_distance_unit = Base::DistanceUnit.find(params[:id])
      @base_distance_unit.destroy

      respond_to do |format|
        format.html { redirect_to base_distance_units_url }
        format.json { head :no_content }
      end
    end
  end
end
